==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/DikiCGI/RequestCommand.pm <==
#
# WiKicker
#
#  Request.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RequestCommand.pm,v 1.1 2004/05/30 04:18:59 naney Exp $
#
#

package WiKicker::DikiCGI::RequestCommand;

use 5.005;
use strict;
use Carp;
use WiKicker::URI;

sub new {
  my ($class, %param) = @_;

  croak __PACKAGE__ . ": No path_info parameter"
    unless exists $param{path_info};

  my $self = bless { path_info => $param{path_info},
                     type => 'd',
                     range_type => 'recent',
                     range => 'recent',
                     name => '',
                   }, $class;

  $self->_initialize;

  return $self;
}

sub type { shift->{type} }
sub range_type { shift->{range_type} }
sub range { shift->{range} }
sub name { shift->{name} }

sub _initialize {
  my $self = shift;

  my $path_info = $self->{path_info};

  $self->{type} = 'd';
  $self->{range_type} = 'recent';
  $self->{name} = '';

  return if $path_info eq '';
  return if $path_info eq '/';
  return if $path_info eq '/d';
  return if $path_info eq '/d.html';
  return if $path_info eq '/d/';

  if ($path_info =~ m!^/d/(.+)(/|.html)$!) {
    $self->_set_range($1);
    return;
  }
  if ($path_info =~ m!^/dn/(.+)(/|.html)$!) {
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }
  if ($path_info =~ m!^/drn/([^/]+)/(.+)(/|.html)$!) {
    $self->_set_range($1);
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }

  if ($path_info eq '/t' || $path_info eq '/t/' || $path_info eq '/t.html') {
    $self->{type} = 't';
    return;
  }
  if ($path_info =~ m!/t/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->_set_range($1);
    return;
  }

  if ($path_info =~ m!/tn/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }


  if ($path_info eq '/k' || $path_info eq '/k/' || $path_info eq '/k.html') {
    $self->{type} = 'k';
    return;
  }

  if ($path_info =~ m!/k/(.+)(/|.html)$!) {
    $self->{type} = 'k';
    $self->{range_type} = 'no';
    $self->{range} = 'no';
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }

  if ($path_info =~ m!/kr/(.+)(/|.html)$!) {
    $self->{type} = 'k';
    $self->_set_range($1);
    return;
  }

  if ($path_info =~ m!/([dt]k)/(.+)(/|.html)$!) {
    $self->{type} = $1;
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }

  if ($path_info =~ m!/trn/([^/]+)/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->_set_range($1);
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }
  if ($path_info =~ m!/([dt]k)r/([^/]+)/(.+)(/|.html)$!) {
    $self->{type} = $1;
    $self->_set_range($2);
    $self->{name} = WiKicker::URI::unescape_URI($3);
    return;
  }
}

sub _set_range {
  my ($self, $range_string) = @_;

  if ($range_string =~ /^(\d\d\d\d)-(.+)$/) { # YYYY-(.+)
    my $rest = $2;
    if ($rest =~ /^(\d\d)-(.+)$/) { # MM-(.+)
      $rest = $2;
      if ($rest =~ /^(\d\d)(.*)$/) { # DD(.*)
        $rest = $2;
        if ($rest eq '') {
          $self->{range_type} = 'day';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^-/) {
          $self->{range_type} = 'article';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:\d\d\d\d-\d\d-\d\d$/) {
          $self->{range_type} = 'day-to-day';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:\d+-$/) {
          $self->{range_type} = 'day-to';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:-\d+$/) {
          $self->{range_type} = 'day-from';
          $self->{range} = $range_string;
          return;
        }
      }
      elsif ($rest =~ /^[abc]$/) {
        $self->{range_type} = 'ten-day';
        $self->{range} = $range_string;
        return;
      }
    }
  }
  elsif ($range_string =~ /^\d\d-\d\d$/) {
    $self->{range_type} = 'month-day';
    $self->{range} = $range_string;
    return;
  }
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/DikiCGI/RequestCommand.pm <==
#
# WiKicker
#
#  Request.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RequestCommand.pm,v 1.6 2005/03/26 12:11:48 naney Exp $
#
#

package WiKicker::DikiCGI::RequestCommand;

use 5.005;
use strict;
use Carp;
use WiKicker::URI;

sub new {
  my ($class, %param) = @_;

  croak __PACKAGE__ . ': No path_info parameter'
    unless exists $param{path_info};

  my $self = bless { path_info => $param{path_info},
                     type => 'd',
                     range_type => 'recent',
                     range => 'recent',
                     name => '',
                     format => 'html',
                   }, $class;

  $self->_initialize;

  return $self;
}

sub type { shift->{type} }
sub range_type { shift->{range_type} }
sub range { shift->{range} }
sub name { shift->{name} }

sub _initialize {
  my $self = shift;

  my $path_info = $self->{path_info};

  $self->{type} = 'd';
  $self->{range_type} = 'recent';
  $self->{name} = '';

  return if $path_info eq '';
  return if $path_info eq '/';
  return if $path_info eq '/d';
  return if $path_info eq '/d.html';
  return if $path_info eq '/d/';

  if ($path_info eq '/d/rss.rdf') {
    $self->{format} = 'rss';
    return;
  }

  if ($path_info =~ m!^/d/(.+)(/|.html)$!) {
    $self->_set_range($1);
    return;
  }
  if ($path_info =~ m!^/dw/(.+)(/|.html)$!) {
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }
  if ($path_info =~ m!^/drw/([^/]+)/(.+)(/|.html)$!) {
    $self->_set_range($1);
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }

  if ($path_info eq '/t' || $path_info eq '/t/' || $path_info eq '/t.html') {
    $self->{type} = 't';
    return;
  }
  if ($path_info =~ m!/t/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->_set_range($1);
    return;
  }

  if ($path_info =~ m!/tw/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }


  if ($path_info eq '/k' || $path_info eq '/k/' || $path_info eq '/k.html') {
    $self->{type} = 'k';
    return;
  }

  if ($path_info =~ m!/k/(.+)(/|.html)$!) {
    $self->{type} = 'k';
    $self->{range_type} = 'no';
    $self->{range} = 'no';
    $self->{name} = WiKicker::URI::unescape_URI($1);
    return;
  }

  if ($path_info =~ m!/([dt]k)/(.+)(/|.html)$!) {
    $self->{type} = $1;
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }

  if ($path_info =~ m!/trw/([^/]+)/(.+)(/|.html)$!) {
    $self->{type} = 't';
    $self->_set_range($1);
    $self->{name} = WiKicker::URI::unescape_URI($2);
    return;
  }
  if ($path_info =~ m!/([dt]k)r/([^/]+)/(.+)(/|.html)$!) {
    $self->{type} = $1;
    $self->_set_range($2);
    $self->{name} = WiKicker::URI::unescape_URI($3);
    return;
  }

  if ($path_info eq '/w' || $path_info eq '/w/' || $path_info eq '/w.html') {
    $self->{type} = 'w';
    $self->{range_type} = 'no';
    $self->{range} = 'no';
    return;
  }

  if ($path_info eq '/term.txt') {
    $self->{type} = 'term_list';
    $self->{range_type} = 'all';
    $self->{format} = 'txt';
    return;
  }
}

sub _set_range {
  my ($self, $range_string) = @_;

  if ($range_string =~ /^(\d\d\d\d)-(.+)$/) { # YYYY-(.+)
    my $rest = $2;
    if ($rest =~ /^(\d\d)-(.+)$/) { # MM-(.+)
      $rest = $2;
      if ($rest =~ /^(\d\d)(.*)$/) { # DD(.*)
        $rest = $2;
        if ($rest eq '') {
          $self->{range_type} = 'day';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^-/) {
          $self->{range_type} = 'article';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:\d\d\d\d-\d\d-\d\d$/) {
          $self->{range_type} = 'day-to-day';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:\d+-$/) {
          $self->{range_type} = 'day-to';
          $self->{range} = $range_string;
          return;
        }
        if ($rest =~ /^:-\d+$/) {
          $self->{range_type} = 'day-from';
          $self->{range} = $range_string;
          return;
        }
      }
      elsif ($rest =~ /^[abc]$/) {
        $self->{range_type} = 'ten-day';
        $self->{range} = $range_string;
        return;
      }
    }
  }
  elsif ($range_string =~ /^\d\d-\d\d$/) {
    $self->{range_type} = 'month-day';
    $self->{range} = $range_string;
    return;
  }
}

sub format {
  shift->{format};
}

1;
